
# Frequently Asked Questions
- [bidsmreye can not find subject / task](#bidsmreye-can-not-find-subject--task)
- [How I should structure my input data?](#how-i-should-structure-my-input-data)
- [Is the "prepare" only suitable for the datasets that have eye-tracking info?](#is-the-prepare-only-suitable-for-the-datasets-that-have-eye-tracking-info)
- [Should I use the automatically generated methods section?](#should-i-use-the-automatically-generated-methods-section)

<a name="bidsmreye-can-not-find-subject--task"></a>
## bidsmreye can not find subject / task

Check the following things:

- Have you passed the correct path to your BIDS dataset?

  This is one the most common errors,
  that can very easily happen when working with a containerized version of bidsmreye

- Is your dataset a valid preprocessed fMRI BIDS dataset?

  See [How I should structure my input data?](./faq.md#how-i-should-structure-my-input-data)

- Try to rerun your command with the `--reset-database` option for force bidsmreye to reindex your input dataset.

<a name="how-i-should-structure-my-input-data"></a>
## How I should structure my input data?

bidsmreye requires a BIDS **preprocessed** dataset as input.

Two bids apps are available to generate those types of preprocessed data:

- [fmriprep](https://fmriprep.org/en/stable/)
- [bidspm](https://bidspm.readthedocs.io/en/latest/general_information.html)

bidsmreye requires your input fmri data:

 - to be minimally preprocessed
 - with [filenames and structure that conforms to a BIDS derivative dataset](https://bids-specification.readthedocs.io/en/latest/derivatives/imaging.html#preprocessed-coregistered-andor-resampled-volumes).

More specifically the dataset should look like this:

```
dataset_description.json
sub-{sub}
    [ses-{session}]
        func (func_dir)
            sub-{sub}[_ses-{session}]_task-{task}[_acq-{acq}][_ce-{ce}][_dir-{dir}][_rec-{rec}][_run-{run_index}]_space-{space}[_res-{res}]_desc-preproc_bold.nii[.gz]
[participants.tsv]
[README]
[CHANGES]
[LICENSE]
```

- Filename entities, files or directories between square brackets
  (for example, `[_ses-<label>]`) are OPTIONAL.
  Note that for bidsmreye to work, the `space` entity is required.
- `[.gz]` means that both the unzipped and gzipped versions of the extension are valid.

Moreover the dataset_description.json file specify
that the input dataset is a derivative dataset:

```json
{
    "Name": "my_dataset",
    "BIDSVersion": "1.8.0",
    "DatasetType": "derivative",
}
```

<a name="is-the-prepare-only-suitable-for-the-datasets-that-have-eye-tracking-info"></a>
## Is the "prepare" only suitable for the datasets that have eye-tracking info?

No the `prepare` action is necessary for all datasets,
whether they have eye-tracking info or not.

This action:

- registers the data to MNI if this is not the case already
- registers the data the the deepmreye template
- extracts data from the eyes mask

In future versions of bidsmreye, this action should also be able to combine
the extracted data with the eye gaze position coming
from preprocessed eyetracking data.

<a name="should-i-use-the-automatically-generated-methods-section"></a>
## Should I use the automatically generated methods section?

See the notes in this
[Nipreps page](https://www.nipreps.org/intro/transparency/#citation-boilerplates)

Also there is this
[blogpost](https://reproducibility.stanford.edu/copy-pasting-your-methods-section-is-good-actually/)
from the Stanford team behind fmriprep.

<hr>

Generated by [FAQtory](https://github.com/willmcgugan/faqtory)
